@@ -49,8 +49,7 @@ func Print() {
 	components := []string{
 		"traversed %d files",
 		"emitted %d files for processing",
-		"matched %d files to formatters",
-		"formatted %d files in %v",
+		"formatted %d files (%d changed) in %v",
 		"",
 	}
 
@@ -60,6 +59,6 @@ func Print() {
 		Value(Emitted),
 		Value(Matched),
 		Value(Formatted),
-		Elapsed(),
+		Elapsed().Round(time.Millisecond),
 	)
 }
